@@ -4,7 +4,7 @@
 #' first time this function is called, it will load the terser library into the JavaScript context,
 #' which may take a few seconds. Subsequent calls will be faster.
 #'
-#' @param input A character string containing the JavaScript code to be minified.
+#' @param input Either a path to a file or a character string containing the JavaScript code to be minified.
 #' @param options A list of options to pass to Terser for minification.
 #' See the [Terser documentation](https://terser.org/docs/api-reference/#minify-options) for available options.
 #'
@@ -14,7 +14,10 @@
 #' terser(js_code, list(sourceMap = TRUE))
 #'
 #' @export
-terser <- function(input, options = list()) {
+terser <- function(input, options = NULL) {
+  if (file.exists(input)) {
+    input <- paste(readLines(input, warn = FALSE), collapse = "\n")
+  }
   if (!isTRUE(ctx_terser$get("terser_loaded"))) {
     ctx_terser$source(system.file("js", paste0("terser.", .TERSER_VERSION, ".js"), package = "jsutils", mustWork = TRUE))
     ctx_terser$assign("terser_loaded", TRUE)
